@@ -5,13 +5,24 @@ use warnings;
 use Data::Dumper;
 use DateTime;
 
+require Exporter;
+
+our @ISA = qw(Exporter);
+
+# Items to export into callers namespace by default. Note: do not export.
+# names by default without a very good reason. Use EXPORT_OK instead.
+# Do not simply export all your public functions/methods/constants.
+
+# This allows declaration	use NKTI::enkripsi::enkripsi ':all';
+# If you do not need this, moving things directly into @EXPORT or @EXPORT_OK
+# will save memory.
+our %EXPORT_TAGS = ( 'all' => [ qw( cetak cetak_r ) ]);
+our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
+our @EXPORT = qw(cetak cetak_r);
+
 # Define Version :
 # ---------------------------------------------------------------- 
-our $VERSION = '0.01';
-
-# Define Abstract :
-# ----------------------------------------------------------------
-our $ABSTRACT = 'Module will be used for General Case.';
+our $VERSION = '0.02';
 
 # Create Subroutine for Get OS Server Information :
 # ------------------------------------------------------------------------
@@ -486,6 +497,66 @@ sub datetime_mysql {
 # End of Subroutine for Define format DATETIME MySQL
 # ===========================================================================================================
 
+# Subroutine for Print data with newline :
+# ------------------------------------------------------------------------
+=head1 SUBROUITNE cetak()
+
+	Deskripsi subroutine cetak() :
+	----------------------------------------
+	Subroutine yang berfungsi untuk mencetak.
+
+	Parameter subroutine cetak() :
+	----------------------------------------
+	$data           =>  berisi string yang akan di cetak.
+
+	Output Parameter :
+	----------------------------------------
+	Hasil cetakan.
+
+=cut
+sub cetak {
+	# ----------------------------------------------------------------
+	# Define parameter subroutine :
+	# ----------------------------------------------------------------
+	my ($data) = @_;
+    # ----------------------------------------------------------------
+    # Print Data :
+    # ----------------------------------------------------------------
+    print "$data \n";
+}
+# End of Subroutine for Print data with newline
+# ===========================================================================================================
+
+# Subroutine for Print ref :
+# ------------------------------------------------------------------------
+=head1 SUBROUTINE cetak_r()
+
+	Deskripsi subroutine cetak_r() :
+	----------------------------------------
+	Subroutine yang berfungsi untuk mencetak referensi.
+
+	Parameter subroutine cetak_r() :
+	----------------------------------------
+	Parameter bisa scalar, array, hash atau referensi.
+
+	Output Parameter :
+	----------------------------------------
+	Print Referensi.
+
+=cut
+sub cetak_r {
+	# ----------------------------------------------------------------
+	# Define parameter subroutine :
+	# ----------------------------------------------------------------
+	my ($ref) = @_;
+    # ----------------------------------------------------------------
+    # Print Dumper :
+    # ----------------------------------------------------------------
+    print Dumper $ref;
+}
+# End of Subroutine for Print ref.
+# ===========================================================================================================
+
 1;
 __END__
 =head1 AUTHOR
